@@ -1,13 +1,14 @@
 #ifndef _RAR_EXTINFO_
 #define _RAR_EXTINFO_
 
-bool IsRelativeSymlinkSafe(const wchar *SrcName,const wchar *TargetName);
-bool ExtractSymlink(CommandData *Cmd,ComprDataIO &DataIO,Archive &Arc,const wchar *LinkName);
+bool LinksToDirs(const wchar *SrcName,const wchar *SkipPart,std::wstring &LastChecked);
+bool IsRelativeSymlinkSafe(CommandData *Cmd,const wchar *SrcName,const wchar *PrepSrcName,const wchar *TargetName);
+bool ExtractSymlink(CommandData *Cmd,ComprDataIO &DataIO,Archive &Arc,const wchar *LinkName,bool &UpLink);
 #ifdef _UNIX
 void SetUnixOwner(Archive &Arc,const wchar *FileName);
 #endif
 
-bool ExtractHardlink(wchar *NameNew,wchar *NameExisting,size_t NameExistingSize);
+bool ExtractHardlink(CommandData *Cmd,wchar *NameNew,wchar *NameExisting,size_t NameExistingSize);
 
 void GetStreamNameNTFS(Archive &Arc,wchar *StreamName,size_t MaxSize);
 
